
#ifndef TEXTADDONSWIDGETS_EXPORT_H
#define TEXTADDONSWIDGETS_EXPORT_H

#ifdef TEXTADDONSWIDGETS_STATIC_DEFINE
#  define TEXTADDONSWIDGETS_EXPORT
#  define TEXTADDONSWIDGETS_NO_EXPORT
#else
#  ifndef TEXTADDONSWIDGETS_EXPORT
#    ifdef KF6TextAddonsWidgets_EXPORTS
        /* We are building this library */
#      define TEXTADDONSWIDGETS_EXPORT __attribute__((visibility("default")))
#    else
        /* We are using this library */
#      define TEXTADDONSWIDGETS_EXPORT __attribute__((visibility("default")))
#    endif
#  endif

#  ifndef TEXTADDONSWIDGETS_NO_EXPORT
#    define TEXTADDONSWIDGETS_NO_EXPORT __attribute__((visibility("hidden")))
#  endif
#endif

#ifndef TEXTADDONSWIDGETS_DEPRECATED
#  define TEXTADDONSWIDGETS_DEPRECATED __attribute__ ((__deprecated__))
#endif

#ifndef TEXTADDONSWIDGETS_DEPRECATED_EXPORT
#  define TEXTADDONSWIDGETS_DEPRECATED_EXPORT TEXTADDONSWIDGETS_EXPORT TEXTADDONSWIDGETS_DEPRECATED
#endif

#ifndef TEXTADDONSWIDGETS_DEPRECATED_NO_EXPORT
#  define TEXTADDONSWIDGETS_DEPRECATED_NO_EXPORT TEXTADDONSWIDGETS_NO_EXPORT TEXTADDONSWIDGETS_DEPRECATED
#endif

/* NOLINTNEXTLINE(readability-avoid-unconditional-preprocessor-if) */
#if 0 /* DEFINE_NO_DEPRECATED */
#  ifndef TEXTADDONSWIDGETS_NO_DEPRECATED
#    define TEXTADDONSWIDGETS_NO_DEPRECATED
#  endif
#endif

#endif /* TEXTADDONSWIDGETS_EXPORT_H */
