// This file was generated by ecm_setup_version(): DO NOT EDIT!

#ifndef TEXTEMOTICONSWIDGETS_VERSION_H
#define TEXTEMOTICONSWIDGETS_VERSION_H

#define TEXTEMOTICONSWIDGETS_VERSION_STRING "1.7.0"
#define TEXTEMOTICONSWIDGETS_VERSION_MAJOR 1
#define TEXTEMOTICONSWIDGETS_VERSION_MINOR 7
#define TEXTEMOTICONSWIDGETS_VERSION_PATCH 0
#define TEXTEMOTICONSWIDGETS_VERSION ((1<<16)|(7<<8)|(0))

#endif
